import { lazy, Suspense } from 'react';
import { BrowserRouter, Switch } from 'react-router-dom';
import { ToastContainer } from 'react-toastify';
import { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';

import s from './App.module.css';
import { getToken } from './redux/authorization/selector'
import {asyncLogout} from './redux/authorization/operations'
import PrivateRoute from './components/Routes/PrivateRoute/PrivateRoute';
import PublicRoute from './components/Routes/PublicRoute/PublicRoute';
import Loader from './components/Loader/Loader';



const AuthPage = lazy(
  () =>
    import(
      './components/AuthPage' /* webpackChunkName: "AuthPage" */
    ),
);



function App() {
  const token = useSelector(getToken)
  const dispatch = useDispatch()

  useEffect(() => {
    if(!localStorage.isChecked) localStorage.isChecked = 'true'
  }, [])

  useEffect(() => {
    const handleKeepIn = () => {
     if (localStorage.isChecked === 'false') dispatch(asyncLogout())
    }
    window.addEventListener("beforeunload",handleKeepIn)
    return () => window.removeEventListener("beforeunload",handleKeepIn)
  }, [dispatch,token])

  return (
    <div className={s.appWrapper}>
      <Suspense fallback={<Loader />}>
        <BrowserRouter>
          <Switch>
            <PrivateRoute exact path="/">
              Home
            </PrivateRoute>
              <PublicRoute  path={'/z/'} restricted>
                <AuthPage />
              </PublicRoute>
          </Switch>
        </BrowserRouter>
      </Suspense>
      
      <ToastContainer
        position="top-right"
        autoClose={3000}
        hideProgressBar={false}
        newestOnTop={false}
        closeOnClick
        rtl={false}
        pauseOnFocusLoss
        draggable
        pauseOnHover
      />
    </div>
  );
}


export default App;
