import { toast } from 'react-toastify';
const axios = require('axios');
axios.defaults.baseURL = 'http://localhost:3000/api';

const error = (message:string) =>
  toast.error(`🔥 ${message}!`, {
    position: 'bottom-left',
    autoClose: 3000,
    hideProgressBar: false,
    closeOnClick: true,
    pauseOnHover: true,
    draggable: true,
    progress: undefined,
  });

const success = (message:string) =>
  toast.success(`⚡ ${message}`, {
    position: 'bottom-left',
    autoClose: 3000,
    hideProgressBar: false,
    closeOnClick: true,
    pauseOnHover: true,
    draggable: true,
    progress: undefined,
  });

const setToken = {
  set(token:string) {
    axios.defaults.headers.common.Authorization = `Bearer ${token}`;
  },
  unset() {
    axios.defaults.headers.common.Authorization = '';
  },
};

const authorizeUser = async (number:string,country:string):Promise<string | undefined> => {
  try {
    const { data : {data} } = await axios.post('/auth/register', { number,country });
    success(`check ${number}`);
    return data
  } catch (e) {
    error('BAD REQUEST');
  }
};

const loginUser = async <T>(number:string,code:string):Promise<T | undefined> => {
  try {
    const { data : {data} } = await axios.post('/auth/login', { number,code });
    success(`AUTHORIZED`);
    return data
  } catch (e) {
    error('UNAUTHORIZED');
  }
};

const updateCredentials = async (name: string,lastName: string):Promise<any> => {
  try {
    const { data : {data} } = await axios.patch('/users/current', { name, lastName });
    success(`CREDENTIALS UPDATED`);
    return data
  } catch (e) {
    error('BAD REQUEST');
  }
};

const updateUserAvatar = async (formData: any): Promise<any> => {
  try {
    const { data : {data} } = await axios.patch('/users/avatars', formData);
    success(`AVATAR UPDATED`);
    return data
  } catch (e) {
    error('BAD REQUEST');
  } 
};



export {
  setToken,
  authorizeUser,
  loginUser,
  updateCredentials,
  updateUserAvatar
};
